stereo.tools.SpatialPatternScore
================================

.. currentmodule:: stereo.tools

.. autoclass:: SpatialPatternScore

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~SpatialPatternScore.__init__
      ~SpatialPatternScore.add_result
      ~SpatialPatternScore.check_param
      ~SpatialPatternScore.fit
      ~SpatialPatternScore.get_params
      ~SpatialPatternScore.sparse2array
   
   

   
   
   